package com.ynet.life.file.parser;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.Region;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonXLSFileParser.class */
public class CommonXLSFileParser implements CommonFileParserInterface {
    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        HSSFRow row = sheet.createRow(0);
        if (titles != null) {
            short s = 0;
            while (true) {
                short i = s;
                if (i >= titles.size()) {
                    break;
                }
                String titleItem = (String) titles.get(i);
                createCell(row, i, titleItem);
                s = (short) (i + 1);
            }
        }
        int rowIndex = 1;
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            int i2 = rowIndex;
            rowIndex++;
            HSSFRow row2 = sheet.createRow(i2);
            short cellIndex = 0;
            for (int i3 = 0; i3 < outputFields.size(); i3++) {
                Object obj = record.get(outputFields.get(i3)) == null ? "" : record.get(outputFields.get(i3));
                String format = (String) outputFormats.get(i3);
                String fieldValue = FileParserUtil.transformFormat(obj.toString(), format);
                short s2 = cellIndex;
                cellIndex = (short) (s2 + 1);
                createCell(row2, s2, fieldValue);
            }
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex3) {
                    Trace.logError("LifeFile", "I/O异常", ex3);
                    throw new TranFailException("EBLN0000", "I/O异常", ex3);
                }
            }
            throw th;
        }
    }

    private void createCell(HSSFRow row, short index, String content) {
        row.createCell(index).setCellValue(new HSSFRichTextString(content));
    }

    private void createCell(HSSFWorkbook wb, HSSFRow row, short index, String content, String fieldType) {
        HSSFCell cell = row.createCell(index);
        if ("amount".equalsIgnoreCase(fieldType)) {
            HSSFCellStyle cellStyle = wb.createCellStyle();
            cellStyle.setAlignment((short) 3);
            cell.setCellType(0);
            cell.setCellStyle(cellStyle);
            cell.setCellValue(new HSSFRichTextString(content));
            return;
        }
        cell.setCellValue(new HSSFRichTextString(content));
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, String title) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        int rowIndex = 0 + 1;
        HSSFRow row = sheet.createRow(0);
        row.setHeightInPoints(20.0f);
        HSSFFont font = workBook.createFont();
        font.setFontName("黑体");
        font.setColor((short) 8);
        font.setFontHeight((short) 300);
        if (titles != null) {
            short s = 0;
            while (true) {
                short i = s;
                if (i >= titles.size()) {
                    break;
                }
                row.createCell(i);
                s = (short) (i + 1);
            }
            sheet.addMergedRegion(new Region(0, (short) 0, 0, (short) (titles.size() - 1)));
            HSSFCellStyle cellStyle = workBook.createCellStyle();
            cellStyle.setAlignment((short) 2);
            cellStyle.setFont(font);
            row.getCell(0).setCellStyle(cellStyle);
            row.getCell(0).setCellValue(new HSSFRichTextString(title));
            HSSFFont titleFont = workBook.createFont();
            titleFont.setFontName("黑体");
            titleFont.setColor((short) 8);
            titleFont.setFontHeight((short) 250);
            HSSFCellStyle titleCellStyle = workBook.createCellStyle();
            titleCellStyle.setAlignment((short) 2);
            titleCellStyle.setVerticalAlignment((short) 1);
            titleCellStyle.setFont(titleFont);
            rowIndex++;
            HSSFRow row2 = sheet.createRow(1);
            row2.setHeightInPoints(20.0f);
            short s2 = 0;
            while (true) {
                short i2 = s2;
                if (i2 >= titles.size()) {
                    break;
                }
                if (outputFormats != null) {
                    sheet.setColumnWidth(i2, Short.parseShort((String) outputFormats.get(i2)));
                }
                String titleItem = (String) titles.get(i2);
                HSSFCell cell = row2.createCell(i2);
                cell.setCellStyle(titleCellStyle);
                cell.setCellValue(new HSSFRichTextString(titleItem));
                s2 = (short) (i2 + 1);
            }
        }
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            int i3 = rowIndex;
            rowIndex++;
            HSSFRow row3 = sheet.createRow(i3);
            short cellIndex = 0;
            for (int i4 = 0; i4 < outputFields.size(); i4++) {
                Object obj = record.get(outputFields.get(i4)) == null ? "" : record.get(outputFields.get(i4));
                short s3 = cellIndex;
                cellIndex = (short) (s3 + 1);
                createCell(row3, s3, obj.toString());
            }
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex3) {
                    Trace.logError("LifeFile", "I/O异常", ex3);
                    throw new TranFailException("EBLN0000", "I/O异常", ex3);
                }
            }
            throw th;
        }
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, String filePathName, String encoding, boolean seqFlag) throws TranFailException {
    }

    @Override // com.ynet.life.file.parser.CommonFileParserInterface
    public void writeToFile(List oneTitles, List twoTitles, List recordList, List outputFields, List titleColWidthFormats, List leftRightColMergeFormats, List topBottomColMergeFormats, String filePathName, String encoding, String reportTitle, List leftRightColMergeNum) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        int rowIndex = 0 + 1;
        HSSFRow row = sheet.createRow(0);
        row.setHeightInPoints(20.0f);
        HSSFFont font = workBook.createFont();
        font.setFontName("黑体");
        font.setColor((short) 8);
        font.setFontHeight((short) 300);
        short s = 0;
        while (true) {
            short i = s;
            if (i >= oneTitles.size()) {
                break;
            }
            row.createCell(i);
            s = (short) (i + 1);
        }
        sheet.addMergedRegion(new Region(0, (short) 0, 0, (short) (oneTitles.size() - 1)));
        HSSFCellStyle cellStyle = workBook.createCellStyle();
        cellStyle.setAlignment((short) 2);
        cellStyle.setFont(font);
        row.getCell(0).setCellStyle(cellStyle);
        row.getCell(0).setCellValue(new HSSFRichTextString(reportTitle));
        HSSFFont titleFont = workBook.createFont();
        titleFont.setFontName("黑体");
        titleFont.setColor((short) 8);
        titleFont.setFontHeight((short) 250);
        HSSFCellStyle titleCellStyle = workBook.createCellStyle();
        titleCellStyle.setAlignment((short) 2);
        titleCellStyle.setVerticalAlignment((short) 1);
        titleCellStyle.setFont(titleFont);
        if (oneTitles != null) {
            rowIndex++;
            HSSFRow row2 = sheet.createRow(1);
            row2.setHeightInPoints(20.0f);
            short s2 = 0;
            while (true) {
                short i2 = s2;
                if (i2 >= oneTitles.size()) {
                    break;
                }
                if (titleColWidthFormats != null) {
                    sheet.setColumnWidth(i2, Short.parseShort((String) titleColWidthFormats.get(i2)));
                }
                String titleItem = (String) oneTitles.get(i2);
                HSSFCell cell = row2.createCell(i2);
                cell.setCellStyle(titleCellStyle);
                cell.setCellValue(new HSSFRichTextString(titleItem));
                s2 = (short) (i2 + 1);
            }
        }
        if (twoTitles != null) {
            int i3 = rowIndex;
            rowIndex++;
            HSSFRow row3 = sheet.createRow(i3);
            row3.setHeightInPoints(20.0f);
            short s3 = 0;
            while (true) {
                short i4 = s3;
                if (i4 >= twoTitles.size()) {
                    break;
                }
                if (titleColWidthFormats != null) {
                    sheet.setColumnWidth(i4, Short.parseShort((String) titleColWidthFormats.get(i4)));
                }
                String titleItem2 = (String) twoTitles.get(i4);
                HSSFCell cell2 = row3.createCell(i4);
                cell2.setCellStyle(titleCellStyle);
                cell2.setCellValue(new HSSFRichTextString(titleItem2));
                s3 = (short) (i4 + 1);
            }
        }
        if (leftRightColMergeFormats != null) {
            for (int i5 = 0; i5 < leftRightColMergeFormats.size(); i5++) {
                short colValue = (short) Integer.parseInt((String) leftRightColMergeFormats.get(i5));
                short colNum = (short) Integer.parseInt((String) leftRightColMergeNum.get(i5));
                sheet.addMergedRegion(new Region(1, colValue, 1, (short) (colValue + colNum)));
            }
        }
        if (topBottomColMergeFormats != null) {
            for (int i6 = 0; i6 < topBottomColMergeFormats.size(); i6++) {
                short rowValue = (short) Integer.parseInt((String) topBottomColMergeFormats.get(i6));
                sheet.addMergedRegion(new Region(1, rowValue, 2, rowValue));
            }
        }
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            int i7 = rowIndex;
            rowIndex++;
            HSSFRow row4 = sheet.createRow(i7);
            short cellIndex = 0;
            for (int i8 = 0; i8 < outputFields.size(); i8++) {
                Object obj = record.get(outputFields.get(i8)) == null ? "" : record.get(outputFields.get(i8));
                short s4 = cellIndex;
                cellIndex = (short) (s4 + 1);
                createCell(row4, s4, obj.toString());
            }
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex3) {
                    Trace.logError("LifeFile", "I/O异常", ex3);
                    throw new TranFailException("EBLN0000", "I/O异常", ex3);
                }
            }
            throw th;
        }
    }
}
